/*
** Module   : AssignTrigger.java
** Abstract : Database assign trigger interface.
**
** Copyright (c) 2004-2009, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description----------------------
** 001 SVL 20091019   @44150 Created initial version. Defines interface to be
**                           used by objects which represent database assign
**                           triggers.
*/

package com.goldencode.p2j.persist.trigger_old;

import com.goldencode.p2j.util.*;
import com.goldencode.p2j.persist.*;

/**
 * Interface which must be implemented by classes which represent database
 * assign triggers.
 */
public interface AssignTrigger
{
   /**
    * Executes the trigger.
    *
    * @param  dmo
    *         DMO which triggered the event (i.e. a new value has been applied
    *         to the specific field of this DMO). It has the new value applied
    *         (if it is a batch update, other new values are applied too). It
    *         should be <code>null</code> if <code>newFieldValue</code> is not
    *         <code>null</code>.
    * @param  newFieldValue
    *         New value of the field which triggered the event. It should be
    *         <code>null</code> if <code>dmo</code> is not <code>null</code>.   
    * @param  oldFieldValue
    *         Old value of the field which triggered the event.
    *
    * @throws ConditionException
    *         May be raised by trigger logic. 
    */
   public void execute(DataModelObject dmo,
                       BaseDataType newFieldValue,
                       BaseDataType oldFieldValue)
   throws ConditionException;
}
