/*
** Module   : DatabaseTrigger.java
** Abstract : Container with data about a database trigger.
**
** Copyright (c) 2010, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description----------------------
** 001 CA  20100527  @44885  Created initial version. Defines a container for 
**                           the properties of a database trigger.
*/

package com.goldencode.p2j.persist.trigger_old;

/**
 * Container class with the properties of a database trigger.
 */
class DatabaseTriggerDef
{
   /**
    * The class of this trigger.
    */
   private final Class triggerClass;
   
   /**
    * Flag indicating that this trigger should execute on undo too.
    */
   private final boolean onUndo;
   
   /**
    * Create a database trigger definition with the specified properties.
    * 
    * @param   triggerClass
    *          The implementing class of this trigger.
    * @param   onUndo
    *          Flag indicating that this trigger should execute on undo too.
    */
   DatabaseTriggerDef(Class triggerClass, boolean onUndo)
   {
      this.triggerClass = triggerClass;
      this.onUndo = onUndo;
   }
   
   /**
    * Get the value of the {@link #onUndo} flag.
    * 
    * @return   <code>true</code> if this trigger should execute on undo.
    */
   public boolean isOnUndo()
   {
      return onUndo;
   }
   
   /**
    * Get the implementing class of this trigger.
    * 
    * @return   The {@link #triggerClass class} of this trigger.
    */
   public Class getTriggerClass()
   {
      return triggerClass;
   }
   
   /**
    * Equality test. The passed object is equal with the object represented by
    * this instance if it is a {@link DatabaseTriggerDef} instance and their 
    * {@link #triggerClass} and {@link #onUndo} fields are the same.
    *
    * @param   o
    *          Another object to compare with this instance.
    *
    * @return  <code>true</code> if this object equals the given one, else
    *          <code>false</code>.
    */
   public boolean equals(Object o)
   {
      if (o == null || !(o instanceof DatabaseTriggerDef))
         return false;
      
      DatabaseTriggerDef trigger = (DatabaseTriggerDef) o;
      
      return trigger.triggerClass.equals(triggerClass) && 
             trigger.onUndo == onUndo;
   }
   
   /**
    * Generate a hash code for a given key, such that all hash codes
    * created are consistent with this object's implementation of the
    * <code>equals</code> method.
    *
    * @return  Hash code for this key.
    */
   public int hashCode()
   {
      int hash = triggerClass.hashCode() * 37;
      hash += onUndo ? Boolean.TRUE.hashCode() : Boolean.FALSE.hashCode();
      
      return hash; 
   }
}